pub struct TerminalGeometry {
pub size: TerminalSize,
pub pixels: Option<TerminalPixels>,
}Expand description
A terminal geometry request including cell dimensions and optional pixels.
Fields
size: TerminalSizeThe terminal size in character cells.
pixels: Option<TerminalPixels>The terminal size in pixels, when the outer terminal exposes it.
Implementations
Sourceimpl TerminalGeometry
impl TerminalGeometry
Sourcepub const fn new(cols: u16, rows: u16) -> TerminalGeometry
pub const fn new(cols: u16, rows: u16) -> TerminalGeometry
Creates terminal geometry from cell dimensions.
Sourcepub const fn from_size(size: TerminalSize) -> TerminalGeometry
pub const fn from_size(size: TerminalSize) -> TerminalGeometry
Creates terminal geometry from an existing cell size.
Sourcepub const fn with_pixels(self, pixels: TerminalPixels) -> TerminalGeometry
pub const fn with_pixels(self, pixels: TerminalPixels) -> TerminalGeometry
Adds pixel dimensions to this geometry.