pub struct TerminalSize {
pub cols: u16,
pub rows: u16,
}Expand description
A terminal geometry request.
Fields
cols: u16The requested column count.
rows: u16The requested row count.
Implementations
Sourceimpl TerminalSize
impl TerminalSize
Sourcepub const fn new(cols: u16, rows: u16) -> TerminalSize
pub const fn new(cols: u16, rows: u16) -> TerminalSize
Creates a terminal size value from column and row counts.
Sourcepub const fn into_geometry(self) -> TerminalGeometry
pub const fn into_geometry(self) -> TerminalGeometry
Returns this cell geometry wrapped as a terminal geometry with no pixel size.